@@ -1,8 +1,9 @@
 /*
  *  data.h - counts the data exchanged
  *
- *  Copyright (C) 1999 Robert Cheramy <tibob@via.ecp.fr>
- *  Copyright (C) 1999 Andres Krapf <dae@via.ecp.fr>
+ *  (c) 1999-2001 Robert Cheramy <tibob@via.ecp.fr>
+ *  (c) 1999      Andres Krapf <dae@via.ecp.fr>
+ *  (c) 2001      Loc Tortay & IN2P3 Computing Center <tortay@cc.in2p3.fr>
  *
  */
 
@@ -25,10 +26,12 @@
 #ifndef DATA_H
 #define DATA_H
 
+#include "filter.h"
+
 #define MAX_DATA_SIZE 100
 
-struct s_data {
-  struct s_data *prev, *next;
+struct ipfm_data {
+  struct ipfm_data *prev, *next;
   u_int32_t ip;
   /* NOTE : the type "unsigned long long" may not work with your compiler.
      please do write us <ipfm@via.ecp.fr> if you are experiencing problems
@@ -37,13 +40,14 @@ struct s_data {
 };
 
 
-void data_add(struct AllLogsType * pLog, u_int32_t ip, int in, int out);
-void data_dump(struct AllLogsType * pLog);
-void data_clear(struct AllLogsType * pLog);
-void DataSort(struct AllLogsType * pLog);
-int DataCompareOut(const void * ptr1, const void * ptr2);
-int DataCompareIn(const void * ptr1, const void * ptr2);
-int DataCompareTotal(const void * ptr1, const void * ptr2);
-void DataFormat(struct AllLogsType * pLog, struct s_data * pData, char * pFormatedData, int BufLen);
+void data_add(struct AllLogsType *pLog, u_int32_t ip, int in, int out);
+void data_dump(struct AllLogsType *pLog);
+void data_clear(struct AllLogsType *pLog);
+void DataSort(struct AllLogsType *pLog);
+int DataCompareOut(const void *ptr1, const void *ptr2);
+int DataCompareIn(const void *ptr1, const void *ptr2);
+int DataCompareTotal(const void *ptr1, const void *ptr2);
+void DataFormat(struct AllLogsType *pLog, struct ipfm_data *pData,
+                char *pFormatedData, int BufLen);
 
 #endif
