@@ -1,8 +1,9 @@
 /*
  *  filter.c - Filtering mechanism
  *  
- *  Copyright (C) 1999 Robert Cheramy <tibob@via.ecp.fr>
- *  Copyright (C) 1999 Andres Krapf <dae@via.ecp.fr>
+ *  (c) 1999-2001 Robert Cheramy <tibob@via.ecp.fr>
+ *  (c) 1999      Andres Krapf <dae@via.ecp.fr>
+ *  (c) 2001      Loc Tortay & IN2P3 Computing Center <tortay@cc.in2p3.fr>
  *
  */
 
@@ -39,22 +40,19 @@
 #include "data.h"
 #include "init.h"
 
-extern struct AllLogsType * pAllLogs;
+extern struct AllLogsType *pAllLogs;
 
 /* is host on subnet address/mask ? */
 int isonsubnet(u_int32_t host, u_int32_t address, u_int32_t mask) {
-  if (((address ^ host) & mask) == 0)
-    return TRUE;
-  return FALSE;
+  return (((address ^ host) & mask) == 0);
 }
 
 /* look if the packet should be selected and handle it */
 void dofilter (struct ip *p_packet) {
-  struct AllLogsType * pTempLog;
+  struct AllLogsType *pTempLog;
 
-  for (pTempLog = pAllLogs; NULL != pTempLog; pTempLog = pTempLog->Next)
-  {
-    struct s_filter *p_filtertemp;
+  for (pTempLog = pAllLogs; NULL != pTempLog; pTempLog = pTempLog->Next) {
+    struct ipfm_filter *p_filtertemp;
   
     /* Look if packet should be logged */
     /* first look IP Source */
@@ -66,9 +64,10 @@ void dofilter (struct ip *p_packet) {
 	/* Does ip_dst match this filter ? */
 	if (isonsubnet(p_packet->ip_dst.s_addr, p_filtertemp->ohost.ip , p_filtertemp->ohost.mask) == p_filtertemp->olog) {
 	  /* Log or Ignore packet ? */
-	  if ((p_filtertemp->tlog & SRC) == SRC) {
+	  if ((p_filtertemp->tlog & IPFM_LOG_FROM) == IPFM_LOG_FROM) {
 	    /* log ip source, so it is output data (upload) */
-	    data_add(pTempLog, p_packet->ip_src.s_addr, 0, ntohs(p_packet->ip_len));
+	    data_add(pTempLog, p_packet->ip_src.s_addr, 0,
+                     ntohs(p_packet->ip_len));
 	  }
 	  /* Match found, no need to look further */
 	  break;
@@ -85,9 +84,10 @@ void dofilter (struct ip *p_packet) {
 	/* Does ip_src match this filter ? */
 	if (isonsubnet(p_packet->ip_src.s_addr, p_filtertemp->ohost.ip , p_filtertemp->ohost.mask) == p_filtertemp->olog) {
 	  /* Log or Ignore packet ? */
-	  if ((p_filtertemp->tlog & DST) == DST) {
+	  if ((p_filtertemp->tlog & IPFM_LOG_TO) == IPFM_LOG_TO) {
 	    /* Log IP destination, so it is input data (download) */
-	    data_add(pTempLog, p_packet->ip_dst.s_addr, ntohs(p_packet->ip_len), 0);
+	    data_add(pTempLog, p_packet->ip_dst.s_addr,
+                     ntohs(p_packet->ip_len), 0);
 	  }
 	  /* Match found, no need to look further */
 	  break;
