@@ -1,8 +1,9 @@
 /*
  *  filter.h - Filtering mechanism
  *  
- *  Copyright (C) 1999 Robert Cheramy <tibob@via.ecp.fr>
- *  Copyright (C) 1999 Andres Krapf <dae@via.ecp.fr>
+ *  (c) 1999-2001 Robert Cheramy <robert@cheramy.net>
+ *  (c) 1999      Andres Krapf <dae@via.ecp.fr>
+ *  (c) 2001      Loc Tortay & IN2P3 Computing Center <tortay@cc.in2p3.fr>
  *
  */
 
@@ -25,36 +26,42 @@
 #ifndef FILTER_H
 #define FILTER_H
 
-#define SRC 1
-#define DST 2
+#include "config.h"
 
-struct s_host {
+/* Log no address */
+#define IPFM_LOG_NONE 0x0000
+/* Log packets coming from "this" address */
+#define IPFM_LOG_FROM 0x0001
+/* Log going to "this" address */
+#define IPFM_LOG_TO   0x0002
+/* Log both addresses */
+#define IPFM_LOG_BOTH 0x0003
+
+struct ipfm_host {
   u_int32_t ip;
   u_int32_t mask;
 };
 
+struct ipfm_filter {
+  struct ipfm_filter *next;
 
-struct s_filter {
-  struct s_filter *next;
-
-  /* Log in table ? NONE (0), FROM (1), TO (2), BOTH (3) */
+  /* Log in table ? NONE, FROM, TO, BOTH */
   int tlog;
   /* IP Match for _t_able log */
-  struct s_host thost;
+  struct ipfm_host thost;
 
   /* What to do with the _o_ther IP of the header */
   /* Do log ? 1 (TRUE) => LOG; 0 (FALSE) => IGNORE */
-  int             olog;
+  int olog;
   /* IP Domain to log */
-  struct s_host   ohost;
+  struct ipfm_host ohost;
 };
 
-struct AllLogsType
-{
-  struct s_filter * Filter;
-  struct s_data * Data;
+struct AllLogsType {
+  struct ipfm_filter *Filter;
+  struct ipfm_data *Data;
 
-  char * LogFile;
+  char *LogFile;
   int DataSize;
   int Sort;
   int (*SortFunc)(const void *, const void *);
@@ -66,7 +73,7 @@ struct AllLogsType
   unsigned long int ClearCounter;
   unsigned long int ClearInterval;
 
-  struct AllLogsType * Next;
+  struct AllLogsType *Next;
 };
 
 void dofilter(struct ip *p_packet);
