@@ -3,10 +3,13 @@
  
   (c) 1999      Andres Krapf <dae@via.ecp.fr>
   (c) 2000      Samuel Hocevar <sam@via.ecp.fr>
+  (c) 2002      Robert Chramy <robert@cheramy.net>
 
-  200010xx : sam   : pid file & daemon mode handling
-  20001107 : tibob : SIGUSR1 handling
-  20001207 : tibob : modifications to have a correct SIGHUP behaviour.
+  200010 : sam   : pid file & daemon mode handling
+  200011 : tibob : SIGUSR1 handling
+  200012 : tibob : modifications to have a correct SIGHUP behaviour.
+  200210 : tibob : command-line configurable pid file.
+  
  */
 
 /*
@@ -27,58 +30,58 @@
 
 #include "config.h"
 
-
 #include <unistd.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <signal.h>
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <sys/wait.h>
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
+#include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/socket.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <time.h>
 #ifdef __OS_LINUX__
 #include <getopt.h>
 #endif /* __OS_LINUX__ */
-#include <time.h>
 
-#include "utils.h"
-#include "pcap.h"
-#include "filter.h"
 #include "data.h"
+#include "filter.h"
 #include "init.h"
+#include "pcap.h"
+#include "utils.h"
 
 char *device = NULL;
 int promisc = DEFAULT_OPTIONS_PROMISC;
 extern int SigHup;
 extern int SigDump;
 extern int checkdump;
-extern struct AllLogsType * pAllLogs;
+extern ipfm_timezone tz;
+extern struct AllLogsType *pAllLogs;
 int run_as_daemon = 1;
 
 int yyparse(void);
 extern int line;
-extern char * device;
+extern char *device;
 extern struct OptionsType Options;
-extern FILE * yyin;
+extern FILE *yyin;
 extern int yyfailed;
 
-
-
 struct OptionsType Options;
 
 void print_help() {
   printf("ipfm version %s\n\n", VERSION);
 #ifdef __OS_LINUX__
   printf("\t-n, --nodaemon:\tdo not run as a daemon\n");
-  printf("\t-c, --config <file>:\tspecify an alternate configuration file\n");
+  printf("\t-c <file>, --config <file>:\tspecify an alternate configuration file\n");
   printf("\t-h, --help:\tdisplay this help and exit\n");
+  printf("\t-p <file>, --pid <file>:\tspecify an alternate pid file\n");
 #else
   printf("\t-n:\tdo not run as a daemon\n");
   printf("\t-c <file>:\tspecify an alternate configuration file\n");
   printf("\t-h:\tdisplay this help and exit\n");
+  printf("\t-p <file>:\tspecify an alternate pid file\n");
 #endif /* __OS_LINUX__ */
   printf("\nPlease report bugs to ipfm@via.ecp.fr\n");
 }
@@ -95,39 +98,49 @@ void ParseCmdLine(int argc, char * argv[]) {
     { "config", 1, NULL, 0 },
     { "help", 0, NULL, 0 },
     { "nodaemon", 0, &run_as_daemon, 0 },
+    { "pidfile", 1, NULL, 0 },
     { NULL, 0, NULL, 0 }
   };
 #endif /* __OS_LINUX__ */
 	
   Options.ConfigFile = NULL;
+  Options.PidFile = NULL;
 
 #ifdef __OS_LINUX__
-  while (EOF != (ch = getopt_long(argc, argv, "hnc:", long_options,
+  while (EOF != (ch = getopt_long(argc, argv, "hnc:p:", long_options,
                                  &option_index))) {
 #else
-  while (EOF != (ch = getopt(argc, argv, "hnc:"))) {
+  while (EOF != (ch = getopt(argc, argv, "hnc:p:"))) {
 #endif /* __OS_LINUX__ */
     switch(ch) {	  
 #ifdef __OS_LINUX__
     case 0:
       switch (option_index) {
-        case 0:
-          free(Options.ConfigFile);
-          Options.ConfigFile = strdup(optarg);
-	  break;
-	case 1:
-          print_help();
-	  exit(0);
-	  break;
-    }
+      case 0:
+        Options.ConfigFile = xstrdup(optarg);
+        break;
+      case 1:
+        print_help();
+        exit(0);
+        break;
+      case 2:
+        run_as_daemon = 0;
+        break;
+      case 3:
+        Options.PidFile = xstrdup(optarg);
+        break;
+      }
+      break;
 #endif /* __OS_LINUX__ */
     case 'c':
-      free(Options.ConfigFile);
-      Options.ConfigFile = strdup(optarg);
+      Options.ConfigFile = xstrdup(optarg);
       break;
     case 'n':
       run_as_daemon = 0;
       break;
+    case 'p':
+      Options.PidFile = xstrdup(optarg);
+      break;
     case 'h':
     case '?':
       print_help();
@@ -144,17 +157,19 @@ void InitOnce()
   signal(SIGCHLD, SigChldHandler);
   signal(SIGUSR1, SigUsr1Handler);
 
-  if (NULL == Options.ConfigFile)
-  {
-    Options.ConfigFile = strdup(DEFAULT_OPTIONS_CONFIGFILE);
+  if (NULL == Options.ConfigFile) {
+    Options.ConfigFile = xstrdup(DEFAULT_OPTIONS_CONFIGFILE);
+  }
+  if (NULL == Options.PidFile) {
+    Options.PidFile = xstrdup(DEFAULT_OPTIONS_PIDFILE);
   }
 }
 
 void ReInit()
 {
-  struct AllLogsType * pNewLog;
+  struct AllLogsType *pNewLog;
 
-  pNewLog = (struct AllLogsType *) malloc (sizeof(struct AllLogsType));
+  pNewLog = xmalloc (sizeof(struct AllLogsType));
   pNewLog->Next = NULL;
   pNewLog->Filter = NULL;
   pNewLog->Data = NULL;
@@ -163,7 +178,7 @@ void ReInit()
   pNewLog->ClearInterval = DEFAULT_OPTIONS_CLEARINTERVAL;
   pNewLog->ClearCounter = DEFAULT_OPTIONS_CLEARCOUNTER;
   pNewLog->NextDump = ((time(NULL) / DEFAULT_OPTIONS_DUMPINTERVAL) + 1) * DEFAULT_OPTIONS_DUMPINTERVAL;
-  pNewLog->LogFile = strdup(DEFAULT_OPTIONS_LOGFILE);
+  pNewLog->LogFile = xstrdup(DEFAULT_OPTIONS_LOGFILE);
   pNewLog->Sort = DEFAULT_OPTIONS_SORT;
   pNewLog->SortFunc = NULL;
   pNewLog->ReverseLookup = DEFAULT_OPTIONS_REVERSELOOKUP;
@@ -171,6 +186,7 @@ void ReInit()
 
   pAllLogs = pNewLog;
 
+  tz = DEFAULT_OPTIONS_TIMEZONE;
   checkdump = 2;
 
   configure();
@@ -178,11 +194,10 @@ void ReInit()
   TestLogs();
 
   if (NULL == device) {
-    device = strdup(pcap_default_device());
+    device = xstrdup(pcap_default_device());
   }
 
-  if(!openpcap(device, promisc))
-  {
+  if(!openpcap(device, promisc)) {
     fprintf(stderr, "[ipfm] Unable to open pcap descriptor on device %s\n", device);
     Exit(-1);
   }
@@ -196,20 +211,18 @@ void Init()
 
 void Clean()
 {
-  struct AllLogsType * pTempLog;
-  struct AllLogsType * pTempLogFree;
-  struct s_filter * pTempRule;
+  struct AllLogsType *pTempLog;
+  struct AllLogsType *pTempLogFree;
+  struct ipfm_filter *pTempRule;
 
 /* clean the rules (deallocate the chained list) */
   
-  for (pTempLog = pAllLogs; NULL != pTempLog;)
-  {
-    while (NULL != pTempLog->Filter)
-    {
+  for (pTempLog = pAllLogs; NULL != pTempLog;) {
+    while (NULL != pTempLog->Filter) {
       pTempRule = pTempLog->Filter;
       pTempLog->Filter = pTempLog->Filter->next;
       if (pTempRule)
-	free(pTempRule);
+	xfree(pTempRule);
       else
 	fprintf(stderr, "[init.c] BUG!\n");
     }
@@ -219,16 +232,15 @@ void Clean()
 
     pTempLogFree = pTempLog;
     pTempLog = pTempLog->Next;
-    free(pTempLogFree);
+    xfree(pTempLogFree);
   }
   pAllLogs = NULL;
 
 /* close the pcap descriptor */
    closepcap();
 
-  if (device)
-  {
-    free(device);
+  if (device) {
+    xfree(device);
     device = NULL;
   }
 }
@@ -238,10 +250,10 @@ void Exit(int errcode)
   Clean();
 
   if (Options.ConfigFile)
-    free(Options.ConfigFile);
+    xfree(Options.ConfigFile);
 
   if (run_as_daemon) {
-    remove_pid (PIDFILE);
+    remove_pid (Options.PidFile);
   }
 
   exit(errcode);
@@ -263,7 +275,7 @@ void SigHupHandler(int a)
 
 void SigTermHandler(int a)
 {
-  struct AllLogsType * pTempLog;
+  struct AllLogsType *pTempLog;
 
   for (pTempLog = pAllLogs; NULL != pTempLog; pTempLog = pTempLog->Next) {
     data_dump(pTempLog);
@@ -274,7 +286,7 @@ void SigTermHandler(int a)
 
 void SigIntHandler(int a)
 {
-  struct AllLogsType * pTempLog;
+  struct AllLogsType *pTempLog;
 
   for (pTempLog = pAllLogs; NULL != pTempLog; pTempLog = pTempLog->Next) {
     data_dump(pTempLog);
@@ -312,9 +324,9 @@ void SigChldHandler(int a)
 
 void TestLogs()
 {
-  struct AllLogsType * pTempLog;
-  struct AllLogsType * pPrevLog;
-  struct AllLogsType * pNextLog;
+  struct AllLogsType *pTempLog;
+  struct AllLogsType *pPrevLog;
+  struct AllLogsType *pNextLog;
 
   pPrevLog = NULL;
   for (pTempLog = pAllLogs; NULL != pTempLog; pTempLog = pNextLog)
@@ -324,7 +336,7 @@ void TestLogs()
       /* wipe this entry out*/
     {
       if (pTempLog->LogFile) {
-	free (pTempLog->LogFile);
+	xfree (pTempLog->LogFile);
       }
 
       if (NULL == pPrevLog) {
@@ -333,7 +345,7 @@ void TestLogs()
 	pPrevLog->Next = pTempLog->Next;
       }
 
-      free (pTempLog);
+      xfree (pTempLog);
     } else {
       /* this entry is kept */
       pPrevLog = pTempLog;
@@ -343,7 +355,6 @@ void TestLogs()
 
 
 void configure() {
-  //  fprintf(stderr, "%s\n", Options.ConfigFile);
   yyin = fopen(Options.ConfigFile, "r");
   if (NULL == yyin) {
     printf("Cannot open configuration file %s.\n", Options.ConfigFile);
