@@ -24,9 +24,9 @@
 #ifndef INIT_H
 #define INIT_H
 
-struct OptionsType
-{
-  char * ConfigFile;
+struct OptionsType {
+  char *ConfigFile;
+  char *PidFile;
 };
 
 void ParseCmdLine(int argc, char *argv[]);
