@@ -4,7 +4,7 @@
  * ipfm@via.ecp.fr                                                   *
  *********************************************************************
 
- (c) 1999-2000 Robert Cheramy <tibob@via.ecp.fr>
+ (c) 1999-2002 Robert Cheramy <robert@cheramy.net>
  (c) 2000      Samuel Hocevar <sam@via.ecp.fr>
  (c) 1999      Andres Krapf <dae@via.ecp.fr>
 
@@ -13,8 +13,9 @@
  * libpcap can be found at ftp://ftp.ee.lbl.gov/libpcap.tar.Z        *
  *********************************************************************
 
- 200010xx: sam & tibob : clear and dump options
-           sam : PID file & daemon mode handling
+ 200010: sam & tibob : clear and dump options
+         sam : PID file & daemon mode handling
+ 200210: tibob : configurable PID file
 
  */
 
@@ -34,33 +35,31 @@
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/socket.h>
+#include <unistd.h>
 #include <netinet/in.h>
 #include <netinet/in_systm.h>
 #include <netinet/ip.h>
-#include <stdlib.h>
-#include <unistd.h>
-// #include <pwd.h>
-#include <string.h>
-#include <stdio.h>
-#include <time.h>
 #include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include <sys/socket.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <time.h>
 
 #include "config.h"
-#include "utils.h"
-#include "pcap.h"
-#include "filter.h"
 #include "data.h"
+#include "filter.h"
 #include "init.h"
+#include "pcap.h"
+#include "utils.h"
 
-// struct passwd *runas;
 struct AllLogsType * pAllLogs = NULL;
 extern int run_as_daemon;
+extern struct OptionsType Options;
 
-int main(int argc, char *argv[])
-{
+int main(int argc, char *argv[]) {
   struct ip *p_packet;
   struct AllLogsType * pTempLog;
   
@@ -70,7 +69,7 @@ int main(int argc, char *argv[])
   
   if (run_as_daemon) {
     /* Check PID */
-    if (check_pid(PIDFILE)) {
+    if (check_pid(Options.PidFile)) {
       printf ("Already running, exiting.\n");
       exit (1);
     }
@@ -84,17 +83,11 @@ int main(int argc, char *argv[])
     umask (022);
 
     /* Write PID file */
-    if (!write_pid(PIDFILE)) {
+    if (!write_pid(Options.PidFile)) {
       exit (1);
     }
   }
   
-  /* Disabled because I can't close the socket as nobody.
-     And I don't feel like using threads now :)
-  runas = getpwnam("nobody");
-  setuid(runas->pw_uid);
-  */
-
   for(;;) {
     p_packet = (struct ip *) getnextippkt();
     
@@ -118,5 +111,5 @@ int main(int argc, char *argv[])
     }
   }
 
-  Exit(0);
+  /* Exit(0); */ /* unreachable */
 }
