@@ -25,7 +25,3 @@ char *pcap_default_device();
 int openpcap(char *device, int promisc);
 void closepcap();
 u_char *getnextippkt();
-#ifdef __OS_LINUX__
-void pcap_set_promisc (char *device);
-void pcap_restore_promisc(void);
-#endif /* __OS_LINUX__ */
