@@ -3,6 +3,7 @@
    
   (c) 1999 Robert Cheramy <tibob@via.ecp.fr>
   (c) 2000 Samuel Hocevar <sam@via.ecp.fr>
+  (c) 2001 Loc Tortay & IN2P3 Computing Center <tortay@cc.in2p3.fr>
 
 */
 
@@ -43,4 +44,7 @@ int check_pid (char *pidfile);
 int read_pid (char *pidfile);
 int write_pid (char *pidfile);
 int remove_pid (char *pidfile);
+void *xmalloc(size_t size);
+void xfree(void *p);
+char *xstrdup(const char *s1);
 #endif
